# qs-mps

qs-mps is a Python package that enables researchers to simulate Quantum Systems with Matrix Product State tensors.

## Installation

You can install qs-mps either by cloning the repository or using pip.

```bash
pip install qs-mps
```

### Clone the Repository

To clone the repository locally, use the following command:

```bash
git clone git@github.com:Fradm98/qs-mps.git

